@@ -1,9 +1,12 @@
 package action
 
 import (
+	luar "layeh.com/gopher-luar"
+
 	"github.com/zyedidia/micro/v2/internal/buffer"
 	"github.com/zyedidia/micro/v2/internal/config"
 	"github.com/zyedidia/micro/v2/internal/display"
+	ulua "github.com/zyedidia/micro/v2/internal/lua"
 	"github.com/zyedidia/micro/v2/internal/screen"
 	"github.com/zyedidia/micro/v2/internal/views"
 	"github.com/zyedidia/tcell/v2"
@@ -148,7 +151,19 @@ func (t *TabList) Display() {
 var Tabs *TabList
 
 func InitTabs(bufs []*buffer.Buffer) {
-	Tabs = NewTabList(bufs)
+	multiopen := config.GetGlobalOption("multiopen").(string)
+	if multiopen == "tab" {
+		Tabs = NewTabList(bufs)
+	} else {
+		Tabs = NewTabList(bufs[:1])
+		for _, b := range bufs[1:] {
+			if multiopen == "vsplit" {
+				MainTab().CurPane().VSplitBuf(b)
+			} else {  // default hsplit
+				MainTab().CurPane().HSplitBuf(b)
+			}
+		}
+	}
 }
 
 func MainTab() *Tab {
@@ -264,6 +279,11 @@ func (t *Tab) SetActive(i int) {
 			p.SetActive(false)
 		}
 	}
+
+	err := config.RunPluginFn("onSetActive", luar.New(ulua.L, MainTab().CurPane()))
+	if err != nil {
+		screen.TermMessage(err)
+	}
 }
 
 // GetPane returns the pane with the given split index
