@@ -1,9 +1,7 @@
 package buffer
 
 import (
-	"unicode/utf8"
-
-	"github.com/zyedidia/micro/internal/util"
+	"github.com/zyedidia/micro/v2/internal/util"
 )
 
 // Loc stores a location
@@ -68,9 +66,9 @@ func DiffLA(a, b Loc, buf *LineArray) int {
 	loc := 0
 	for i := a.Y + 1; i < b.Y; i++ {
 		// + 1 for the newline
-		loc += utf8.RuneCount(buf.LineBytes(i)) + 1
+		loc += util.CharacterCount(buf.LineBytes(i)) + 1
 	}
-	loc += utf8.RuneCount(buf.LineBytes(a.Y)) - a.X + b.X + 1
+	loc += util.CharacterCount(buf.LineBytes(a.Y)) - a.X + b.X + 1
 	return loc
 }
 
@@ -80,7 +78,7 @@ func (l Loc) right(buf *LineArray) Loc {
 		return Loc{l.X + 1, l.Y}
 	}
 	var res Loc
-	if l.X < utf8.RuneCount(buf.LineBytes(l.Y)) {
+	if l.X < util.CharacterCount(buf.LineBytes(l.Y)) {
 		res = Loc{l.X + 1, l.Y}
 	} else {
 		res = Loc{0, l.Y + 1}
@@ -97,7 +95,7 @@ func (l Loc) left(buf *LineArray) Loc {
 	if l.X > 0 {
 		res = Loc{l.X - 1, l.Y}
 	} else {
-		res = Loc{utf8.RuneCount(buf.LineBytes(l.Y - 1)), l.Y - 1}
+		res = Loc{util.CharacterCount(buf.LineBytes(l.Y - 1)), l.Y - 1}
 	}
 	return res
 }
